@@ -545,7 +545,7 @@ void MainProgramPrimitive(InputPrimitive *inputPrimitive, int nProc, int rank)
         if (inputPrimitive->areaFileType == 0){
             for (i = 0; i < blockNum; i++){
                 if (SobsAll[i] != 0){
-                    fprintf(fpOut, "%ld-%ld\t%ld\t%s\t%ld\t%.10lf\t%.10lf\n", 
+                    fprintf(fpOut, "%ld-%ld\t%ld\t%s\t%ld\t%.3e\t%.3e\n", 
                             blockArea[i],
                             blockArea[i+1],
                             linkSNPNum[i],
@@ -565,7 +565,7 @@ void MainProgramPrimitive(InputPrimitive *inputPrimitive, int nProc, int rank)
         else {
             for (i = 0; i < blockNum; i++){
                 if (SobsAll[i] != 0){
-                    fprintf(fpOut, "%ld-%ld\t%ld\t%s\t%ld\t%.10lf\t%.10lf\n", 
+                    fprintf(fpOut, "%ld-%ld\t%ld\t%s\t%ld\t%.3e\t%.3e\n", 
                             snpData1[ linkSNPStart[i] ].pos,
                             snpData1[ linkSNPStart[i] + linkSNPNum[i] - 1 ].pos,
                             linkSNPNum[i],
